<?php
/*  Copyright 2009  Alexandre Hoyau  (email : lex [at] silex-ria . org)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
/**
 * @package exchange-platform
 * @author http://lex.silex.tv/
 * @version 1
 */
/**
 * This class is used to handle the requests to getInfo, getChildCategories and getPostsInCategory<br />
 * The Exchange Platform plugin gives access to the posts of the exchange platform and the associated metadat through this class.
 */
class EPItemData
{
	/**
	 * retrieve information from an element from its WP id<br />
	 * contains all the info including the version XML of the element and the link to the zipped file<br />
	 * contains the post content in HTML<br />
	 * contains the details about the Author, The Creation And The update date date<br />
	 * @return an associative array containing the info<br />
	 */
	public function getInfo($idPostWordpress)
	{
		// retrieve an array with the post data
		$postArray = get_post($idPostWordpress,'ARRAY_A');
		$custom_fields = get_post_custom($postArray['ID']);
		
		// handles enclosures and custom fields
		$postArray['customTags'] = array();
		foreach ( $custom_fields as $custom_key => $custom_value)
		{
			//$postArray['customTags'][$custom_key] = array();
			foreach ( $custom_value as $key => $value )
			{
				$postArray['customTags'][$custom_key] = $custom_value;
			}
		}
		
		// handles author data
		$authorId = $postArray['post_author'];
		$postArray['post_author'] = array(); 
		$postArray['post_author']['ID'] = $authorId;
		// $postArray['post_author']['user_login'] = get_the_author_meta( 'user_login', $authorId );
		// $postArray['post_author']['display_name'] = get_the_author_meta( 'display_name', $authorId );
		$postArray['post_author']['nickname'] = get_the_author_meta( 'nickname', $authorId );
		$postArray['post_author']['user_nicename'] = get_the_author_meta( 'user_nicename', $authorId );
		$postArray['post_author']['user_url'] = get_the_author_meta( 'user_url', $authorId );
		$postArray['post_author']['description'] = get_the_author_meta( 'description', $authorId );
		$postArray['post_author']['user_email'] = str_replace('@',' [at] ',get_the_author_meta( 'user_email', $authorId ));

		// return the array
		return $postArray;
	}
	/**
	 * get a paged list of posts for a given category<br />
	 * @return an indexed array of associative arrays containing the info of the posts<br />
	 */
	public function getPostsInCategory($categoryId=0,$itemsPerPage=0,$pageNumber=0)
	{
		$ret = array();
		$arg = array();
		// handle filter by category name
		if ($categoryId>0)
			$arg['cat'] = $categoryId;
		// handle maximum number of posts
		if ($itemsPerPage>0)
			$arg['posts_per_page'] = $itemsPerPage;
		if ($pageNumber>0)
		{
			$offset = $pageNumber * $itemsPerPage;
			$arg['offset'] = $offset;
		}
		// apply filter on posts
		$posts = get_posts($arg);
		
		foreach ($posts as $post)
		{
			$ret[] = $this->getInfo($post->ID);
		}
		return $ret;
	}
	/**
	 * get a list of categories<br />
	 * it means the sub categories of a given category, the first level categories by default<br />
	 * @return an indexed array of associative arrays containing the info of a category<br />
	 */
	public function getChildCategories($parentCategoryId=0)
	{
		$ret = array();
		$args = array();
		//$args['parent'] = $parentCategoryId;
		$args['parent'] = $parentCategoryId;
		$args['hierarchical'] = 1;
		$args['hide_empty'] = 0;
		//$args[''] = ;

		$categories = get_categories($args);
		
		return $categories;
		
/*		foreach ($categories as $cat) 
		{
			// retrieve category data
			$ret[] = get_category($cat->cat_ID,OBJECT);
		}
		return $ret;
*/
	}
	/////////////////////////////	/////////////////////////////
	/**
	 * dependencies for the post
	 */
	function setDependencies($dependencies,$post_ID) {
		update_post_meta($post_ID, '_epDependencies', $dependencies);
	}
	/**
	 * dependencies for the post
	 */
	function getDependencies($post_ID) {
		$result = get_post_meta($post_ID,'_epDependencies');
		$result = $result[0];
		if ($result == '') $result = array();
		return $result;
	}
	/////////////////////////////	/////////////////////////////
	/**
	 * write in the post meta the selected project for a given post ID
	 */
	function setSelectedProject($selectedProject,$post_ID) {

		update_post_meta($post_ID, '_selectedProject', $selectedProject);

	}
	/**
	 * look in the post meta and returns the selected project for a given post ID
	 */
	function getSelectedProject($post_ID) {
		$result = get_post_meta($post_ID,'_selectedProject');
		return $result[0];
	}
	/////////////////////////////	/////////////////////////////
	/**
	 * write in the post meta a message in order to display it when it is the right time (not in an ajax call for example)
	 */
	function setLastMessage($lastMessage,$post_ID) {
		update_post_meta($post_ID, '_epLastMessage', addslashes($lastMessage));
	}
	/**
	 * get a message in the post meta in order to display it when it is the right time (not in an ajax call for example)
	 */
	function getLastMessage($post_ID) {
		$result = get_post_meta($post_ID,'_epLastMessage');
		return $result[0];
	}
	/**
	 * write in the post meta a message in order to display it when it is the right time (not in an ajax call for example)
	 */
	function setLastError($lastError,$post_ID) {
		update_post_meta($post_ID, '_epLastError', addslashes($lastError));
	}
	/**
	 * get a message in the post meta in order to display it when it is the right time (not in an ajax call for example)
	 */
	function getLastError($post_ID) {
		$result = get_post_meta($post_ID,'_epLastError');
		return $result[0];
	}
	/////////////////////////////	/////////////////////////////
	/**
	 * write in the post meta and returns the selected version for a given post ID
	 */
	function setSelectedVersions($selectedVersionsArray,$post_ID) {
		update_post_meta($post_ID, '_selectedVersionsArray', implode(',',$selectedVersionsArray));
	}
	/**
	 * look in the post meta and returns the selected version for a given post ID
	 */
	function getSelectedVersions($post_ID) {
		$result = get_post_meta($post_ID,'_selectedVersionsArray');
		return explode(',',$result[0]);
	}
	/////////////////////////////	/////////////////////////////
	/**
	 * look in the post meta and returns the current item version for a given post ID
	 */
	function getItemCurrentVersion($post_ID) {
		$result = get_post_meta($post_ID,'_itemCurrentVersion');
		return $result[0];
	}
	/**
	 * write in the post meta and returns the current item version for a given post ID
	 */
	function setItemCurrentVersion($itemCurrentVersion,$post_ID) {
		update_post_meta($post_ID, '_itemCurrentVersion', $itemCurrentVersion);
	}
	/////////////////////////////	/////////////////////////////
	/**
	 * look in the post meta and returns the current item version for a given post ID
	 */
	function getCurrentFileName($post_ID) {
		$result = get_post_meta($post_ID,'_itemCurrentFileName');
		return $result[0];
	}
	/**
	 * write in the post meta and returns the current item version for a given post ID
	 */
	function setCurrentFileName($itemCurrentVersion,$post_ID) {
		update_post_meta($post_ID, '_itemCurrentFileName', addslashes($itemCurrentVersion));
	}
	/////////////////////////////	/////////////////////////////
	/**
	 * convert an array to RSS
	 */
	static function echoAsRSS($itemsArray)
	{
		header('Content-Type: ' . feed_content_type('rss-http') . '; charset=' . get_option('blog_charset'), true);
		$more = 1;

		echo '<?xml version="1.0" encoding="'.get_option('blog_charset').'"?'.'>';

?><rss version="2.0"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:atom="http://www.w3.org/2005/Atom"
	xmlns:sy="http://purl.org/rss/1.0/modules/syndication/"
	xmlns:slash="http://purl.org/rss/1.0/modules/slash/" <?php do_action('rss2_ns'); ?>>
<channel>
	<title><?php bloginfo_rss('name'); wp_title_rss(); echo " ".$feed_name?></title>
	<atom:link href="<?php self_link(); ?>" rel="self" type="application/rss+xml" />
	<link><?php bloginfo_rss('url') ?></link>
	<description><?php bloginfo_rss("description") ?></description>
	<lastBuildDate><?php echo mysql2date('D, d M Y H:i:s +0000', get_lastpostmodified('GMT'), false); ?></lastBuildDate>
	<?php the_generator( 'rss2' ); ?>
	<language><?php echo get_option('rss_language'); ?></language><?php
		foreach ($itemsArray as $item)
		{	
?>

	<item><?php
			echo self::propertiesToString($item,3);
?>

	</item><?php
		}
?>

</channel>
</rss><?php
	}
	/**
	 * 
	 */ 
	static public function propertiesToString($item,$indent=0)
	{
		// indentation
		$indentString = '';
		for($idx=0;$idx<$indent;$idx++)
			$indentString .= '    ';
			
		// loop
		$resXML = "";
		foreach ($item as $key => $value)
		{
			if(strpos($key,'password')===FALSE)
			{
				if (is_numeric($key)) $key = 'element';
				$resXML .= "\n$indentString<$key>";
				if (is_array($value) || is_object($value))
				{
					$resXML .= self::propertiesToString($value,$indent+1)."\n$indentString";
				}
				else
					$resXML .= '<![CDATA['.$value.']]>';
				$resXML .= "</$key>";
			}
		}
		return $resXML;
	}
}
?>